Class: Mailtrap::InboundMessagesListResponse

Inherits:
Struct
  • Object
show all
Defined in:
lib/mailtrap/inbound_messages_list_response.rb

Overview

Data Transfer Object for a paginated list of inbound messages

Instance Attribute Summary collapse

Instance Attribute Details

#dataArray<InboundMessage> (readonly)

The messages on this page

Returns:



9
10
11
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9

def data
  @data
end

#last_idString? (readonly)

Cursor for the next page, or nil if this is the last page

Returns:

  • (String, nil)

    the current value of last_id



9
10
11
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9

def last_id
  @last_id
end

#total_countInteger (readonly)

Total number of messages in the inbox

Returns:

  • (Integer)

    the current value of total_count



9
10
11
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9

def total_count
  @total_count
end