Class: Mailtrap::InboundThreadsListResponse
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::InboundThreadsListResponse
- Defined in:
- lib/mailtrap/inbound_threads_list_response.rb
Overview
Data Transfer Object for a paginated list of inbound threads
Instance Attribute Summary collapse
-
#data ⇒ Array<InboundThread>
readonly
The threads on this page.
-
#last_id ⇒ String?
readonly
Cursor for the next page, or nil if this is the last page.
-
#total_count ⇒ Integer
readonly
Total number of threads in the inbox.
Instance Attribute Details
#data ⇒ Array<InboundThread> (readonly)
The threads on this page
9 10 11 |
# File 'lib/mailtrap/inbound_threads_list_response.rb', line 9 def data @data end |
#last_id ⇒ String? (readonly)
Cursor for the next page, or nil if this is the last page
9 10 11 |
# File 'lib/mailtrap/inbound_threads_list_response.rb', line 9 def last_id @last_id end |
#total_count ⇒ Integer (readonly)
Total number of threads in the inbox
9 10 11 |
# File 'lib/mailtrap/inbound_threads_list_response.rb', line 9 def total_count @total_count end |