Class: Mailtrap::TrackingOptOutsListResponse

Inherits:
Struct
  • Object
show all
Defined in:
lib/mailtrap/tracking_opt_outs_list_response.rb

Overview

Data Transfer Object for a paginated list of tracking opt-outs

Instance Attribute Summary collapse

Instance Attribute Details

#dataArray<TrackingOptOut> (readonly)

The tracking opt-outs on this page

Returns:



8
9
10
# File 'lib/mailtrap/tracking_opt_outs_list_response.rb', line 8

def data
  @data
end

#last_idString? (readonly)

Cursor for the next page, or nil if this is the last page

Returns:

  • (String, nil)

    the current value of last_id



8
9
10
# File 'lib/mailtrap/tracking_opt_outs_list_response.rb', line 8

def last_id
  @last_id
end