Class: Mailtrap::EmailLogMessage

Inherits:
Struct
  • Object
show all
Defined in:
lib/mailtrap/email_log_message.rb

Overview

Data Transfer Object for an email log message (summary in list, full details when fetched by ID)

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString? (readonly)

Message category

Returns:

  • (String, nil)

    the current value of category



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def category
  @category
end

#clicks_countInteger (readonly)

Number of clicks

Returns:

  • (Integer)

    the current value of clicks_count



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def clicks_count
  @clicks_count
end

#client_ipString? (readonly)

Client IP that sent the email

Returns:

  • (String, nil)

    the current value of client_ip



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def client_ip
  @client_ip
end

#custom_variablesHash? (readonly)

Custom variables

Returns:

  • (Hash, nil)

    the current value of custom_variables



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def custom_variables
  @custom_variables
end

#eventsArray<EmailLogEvent>? (readonly)

Event list (only when fetched by ID)

Returns:



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def events
  @events
end

#fromString (readonly)

Sender address

Returns:

  • (String)

    the current value of from



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def from
  @from
end

#in_reply_toString? (readonly)

Value of the RFC 5322 In-Reply-To header

Returns:

  • (String, nil)

    the current value of in_reply_to



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def in_reply_to
  @in_reply_to
end

#message_idString (readonly)

Message UUID

Returns:

  • (String)

    the current value of message_id



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def message_id
  @message_id
end

#opens_countInteger (readonly)

Number of opens

Returns:

  • (Integer)

    the current value of opens_count



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def opens_count
  @opens_count
end

#raw_message_urlString? (readonly)

Signed URL to download raw .eml (only when fetched by ID)

Returns:

  • (String, nil)

    the current value of raw_message_url



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def raw_message_url
  @raw_message_url
end

#referencesArray<String> (readonly)

Values of the RFC 5322 References header

Returns:

  • (Array<String>)

    the current value of references



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def references
  @references
end

#rfc_message_idString? (readonly)

Value of the RFC 5322 Message-ID header

Returns:

  • (String, nil)

    the current value of rfc_message_id



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def rfc_message_id
  @rfc_message_id
end

#sending_domain_idInteger (readonly)

Sending domain ID

Returns:

  • (Integer)

    the current value of sending_domain_id



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def sending_domain_id
  @sending_domain_id
end

#sending_streamString (readonly)

transactional or bulk

Returns:

  • (String)

    the current value of sending_stream



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def sending_stream
  @sending_stream
end

#sent_atString (readonly)

ISO 8601 timestamp

Returns:

  • (String)

    the current value of sent_at



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def sent_at
  @sent_at
end

#statusString (readonly)

delivered, not_delivered, enqueued, opted_out

Returns:

  • (String)

    the current value of status



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def status
  @status
end

#subjectString? (readonly)

Email subject

Returns:

  • (String, nil)

    the current value of subject



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def subject
  @subject
end

#template_idInteger? (readonly)

Template ID if sent from template

Returns:

  • (Integer, nil)

    the current value of template_id



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def template_id
  @template_id
end

#template_variablesHash? (readonly)

Template variables

Returns:

  • (Hash, nil)

    the current value of template_variables



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def template_variables
  @template_variables
end

#thread_idString? (readonly)

ID of the inbound thread this message belongs to, if any

Returns:

  • (String, nil)

    the current value of thread_id



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def thread_id
  @thread_id
end

#toString (readonly)

Recipient address

Returns:

  • (String)

    the current value of to



27
28
29
# File 'lib/mailtrap/email_log_message.rb', line 27

def to
  @to
end