Class: Mailtrap::EmailLogMessage
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::EmailLogMessage
- Defined in:
- lib/mailtrap/email_log_message.rb
Overview
Data Transfer Object for an email log message (summary in list, full details when fetched by ID)
Instance Attribute Summary collapse
-
#category ⇒ String?
readonly
Message category.
-
#clicks_count ⇒ Integer
readonly
Number of clicks.
-
#client_ip ⇒ String?
readonly
Client IP that sent the email.
-
#custom_variables ⇒ Hash?
readonly
Custom variables.
-
#events ⇒ Array<EmailLogEvent>?
readonly
Event list (only when fetched by ID).
-
#from ⇒ String
readonly
Sender address.
-
#in_reply_to ⇒ String?
readonly
Value of the RFC 5322 In-Reply-To header.
-
#message_id ⇒ String
readonly
Message UUID.
-
#opens_count ⇒ Integer
readonly
Number of opens.
-
#raw_message_url ⇒ String?
readonly
Signed URL to download raw .eml (only when fetched by ID).
-
#references ⇒ Array<String>
readonly
Values of the RFC 5322 References header.
-
#rfc_message_id ⇒ String?
readonly
Value of the RFC 5322 Message-ID header.
-
#sending_domain_id ⇒ Integer
readonly
Sending domain ID.
-
#sending_stream ⇒ String
readonly
transactional or bulk.
-
#sent_at ⇒ String
readonly
ISO 8601 timestamp.
-
#status ⇒ String
readonly
delivered, not_delivered, enqueued, opted_out.
-
#subject ⇒ String?
readonly
Email subject.
-
#template_id ⇒ Integer?
readonly
Template ID if sent from template.
-
#template_variables ⇒ Hash?
readonly
Template variables.
-
#thread_id ⇒ String?
readonly
ID of the inbound thread this message belongs to, if any.
-
#to ⇒ String
readonly
Recipient address.
Instance Attribute Details
#category ⇒ String? (readonly)
Message category
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def category @category end |
#clicks_count ⇒ Integer (readonly)
Number of clicks
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def clicks_count @clicks_count end |
#client_ip ⇒ String? (readonly)
Client IP that sent the email
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def client_ip @client_ip end |
#custom_variables ⇒ Hash? (readonly)
Custom variables
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def custom_variables @custom_variables end |
#events ⇒ Array<EmailLogEvent>? (readonly)
Event list (only when fetched by ID)
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def events @events end |
#from ⇒ String (readonly)
Sender address
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def from @from end |
#in_reply_to ⇒ String? (readonly)
Value of the RFC 5322 In-Reply-To header
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def in_reply_to @in_reply_to end |
#message_id ⇒ String (readonly)
Message UUID
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def @message_id end |
#opens_count ⇒ Integer (readonly)
Number of opens
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def opens_count @opens_count end |
#raw_message_url ⇒ String? (readonly)
Signed URL to download raw .eml (only when fetched by ID)
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def @raw_message_url end |
#references ⇒ Array<String> (readonly)
Values of the RFC 5322 References header
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def references @references end |
#rfc_message_id ⇒ String? (readonly)
Value of the RFC 5322 Message-ID header
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def @rfc_message_id end |
#sending_domain_id ⇒ Integer (readonly)
Sending domain ID
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def sending_domain_id @sending_domain_id end |
#sending_stream ⇒ String (readonly)
transactional or bulk
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def sending_stream @sending_stream end |
#sent_at ⇒ String (readonly)
ISO 8601 timestamp
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def sent_at @sent_at end |
#status ⇒ String (readonly)
delivered, not_delivered, enqueued, opted_out
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def status @status end |
#subject ⇒ String? (readonly)
Email subject
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def subject @subject end |
#template_id ⇒ Integer? (readonly)
Template ID if sent from template
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def template_id @template_id end |
#template_variables ⇒ Hash? (readonly)
Template variables
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def template_variables @template_variables end |
#thread_id ⇒ String? (readonly)
ID of the inbound thread this message belongs to, if any
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def thread_id @thread_id end |
#to ⇒ String (readonly)
Recipient address
27 28 29 |
# File 'lib/mailtrap/email_log_message.rb', line 27 def to @to end |