Class: Mailtrap::EmailLogMessage
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::EmailLogMessage
- Defined in:
- lib/mailtrap/email_log_message.rb
Overview
Data Transfer Object for an email log message (summary in list, full details when fetched by ID)
Instance Attribute Summary collapse
-
#category ⇒ String?
readonly
Message category.
-
#clicks_count ⇒ Integer
readonly
Number of clicks.
-
#client_ip ⇒ String?
readonly
Client IP that sent the email.
-
#custom_variables ⇒ Hash?
readonly
Custom variables.
-
#events ⇒ Array<EmailLogEvent>?
readonly
Event list (only when fetched by ID).
-
#from ⇒ String
readonly
Sender address.
-
#message_id ⇒ String
readonly
Message UUID.
-
#opens_count ⇒ Integer
readonly
Number of opens.
-
#raw_message_url ⇒ String?
readonly
Signed URL to download raw .eml (only when fetched by ID).
-
#sending_domain_id ⇒ Integer
readonly
Sending domain ID.
-
#sending_stream ⇒ String
readonly
transactional or bulk.
-
#sent_at ⇒ String
readonly
ISO 8601 timestamp.
-
#status ⇒ String
readonly
delivered, not_delivered, enqueued, opted_out.
-
#subject ⇒ String?
readonly
Email subject.
-
#template_id ⇒ Integer?
readonly
Template ID if sent from template.
-
#template_variables ⇒ Hash?
readonly
Template variables.
-
#to ⇒ String
readonly
Recipient address.
Instance Attribute Details
#category ⇒ String? (readonly)
Message category
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def category @category end |
#clicks_count ⇒ Integer (readonly)
Number of clicks
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def clicks_count @clicks_count end |
#client_ip ⇒ String? (readonly)
Client IP that sent the email
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def client_ip @client_ip end |
#custom_variables ⇒ Hash? (readonly)
Custom variables
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def custom_variables @custom_variables end |
#events ⇒ Array<EmailLogEvent>? (readonly)
Event list (only when fetched by ID)
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def events @events end |
#from ⇒ String (readonly)
Sender address
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def from @from end |
#message_id ⇒ String (readonly)
Message UUID
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def @message_id end |
#opens_count ⇒ Integer (readonly)
Number of opens
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def opens_count @opens_count end |
#raw_message_url ⇒ String? (readonly)
Signed URL to download raw .eml (only when fetched by ID)
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def @raw_message_url end |
#sending_domain_id ⇒ Integer (readonly)
Sending domain ID
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def sending_domain_id @sending_domain_id end |
#sending_stream ⇒ String (readonly)
transactional or bulk
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def sending_stream @sending_stream end |
#sent_at ⇒ String (readonly)
ISO 8601 timestamp
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def sent_at @sent_at end |
#status ⇒ String (readonly)
delivered, not_delivered, enqueued, opted_out
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def status @status end |
#subject ⇒ String? (readonly)
Email subject
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def subject @subject end |
#template_id ⇒ Integer? (readonly)
Template ID if sent from template
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def template_id @template_id end |
#template_variables ⇒ Hash? (readonly)
Template variables
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def template_variables @template_variables end |
#to ⇒ String (readonly)
Recipient address
23 24 25 |
# File 'lib/mailtrap/email_log_message.rb', line 23 def to @to end |