Class: Mailtrap::InboundMessagesListResponse
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::InboundMessagesListResponse
- Defined in:
- lib/mailtrap/inbound_messages_list_response.rb
Overview
Data Transfer Object for a paginated list of inbound messages
Instance Attribute Summary collapse
-
#data ⇒ Array<InboundMessage>
readonly
The messages on this page.
-
#last_id ⇒ String?
readonly
Cursor for the next page, or nil if this is the last page.
-
#total_count ⇒ Integer
readonly
Total number of messages in the inbox.
Instance Attribute Details
#data ⇒ Array<InboundMessage> (readonly)
The messages on this page
9 10 11 |
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9 def data @data end |
#last_id ⇒ String? (readonly)
Cursor for the next page, or nil if this is the last page
9 10 11 |
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9 def last_id @last_id end |
#total_count ⇒ Integer (readonly)
Total number of messages in the inbox
9 10 11 |
# File 'lib/mailtrap/inbound_messages_list_response.rb', line 9 def total_count @total_count end |