Class: Mailtrap::SandboxMessage
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::SandboxMessage
- Defined in:
- lib/mailtrap/sandbox_message.rb
Overview
Data Transfer Object for Sandbox Message
Instance Attribute Summary collapse
-
#blacklists_report_info ⇒ Boolean
readonly
Information about blacklists report.
-
#created_at ⇒ String
readonly
The timestamp when the message was created.
-
#download_path ⇒ String
readonly
The path to download the email.
-
#email_size ⇒ Integer
readonly
The size of the email in bytes.
-
#from_email ⇒ String
readonly
The sender’s email address.
-
#from_name ⇒ String
readonly
The sender’s name.
-
#html_body_size ⇒ Integer
readonly
The size of the HTML body in bytes.
-
#html_path ⇒ String
readonly
The path to the HTML version of the email.
-
#html_source_path ⇒ String
readonly
The path to the HTML source of the email.
-
#human_size ⇒ String
readonly
The human-readable size of the email.
-
#id ⇒ Integer
readonly
The message ID.
-
#inbox_id ⇒ Integer
readonly
The inbox ID.
-
#is_read ⇒ Boolean
readonly
Whether the message has been read.
-
#raw_path ⇒ String
readonly
The path to the raw version of the email.
-
#sent_at ⇒ String
readonly
The timestamp when the message was sent.
-
#smtp_information ⇒ Hash
readonly
Information about SMTP.
-
#subject ⇒ String
readonly
The message subject.
-
#text_body_size ⇒ Integer
readonly
The size of the text body in bytes.
-
#to_email ⇒ String
readonly
The recipient’s email address.
-
#to_name ⇒ String
readonly
The recipient’s name.
-
#txt_path ⇒ String
readonly
The path to the text version of the email.
-
#updated_at ⇒ String
readonly
The timestamp when the message was last updated.
Instance Method Summary collapse
-
#read? ⇒ Boolean
Whether the message has been read.
Instance Attribute Details
#blacklists_report_info ⇒ Boolean (readonly)
Information about blacklists report
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def blacklists_report_info @blacklists_report_info end |
#created_at ⇒ String (readonly)
The timestamp when the message was created
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def created_at @created_at end |
#download_path ⇒ String (readonly)
The path to download the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def download_path @download_path end |
#email_size ⇒ Integer (readonly)
The size of the email in bytes
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def email_size @email_size end |
#from_email ⇒ String (readonly)
The sender’s email address
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def from_email @from_email end |
#from_name ⇒ String (readonly)
The sender’s name
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def from_name @from_name end |
#html_body_size ⇒ Integer (readonly)
The size of the HTML body in bytes
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def html_body_size @html_body_size end |
#html_path ⇒ String (readonly)
The path to the HTML version of the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def html_path @html_path end |
#html_source_path ⇒ String (readonly)
The path to the HTML source of the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def html_source_path @html_source_path end |
#human_size ⇒ String (readonly)
The human-readable size of the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def human_size @human_size end |
#id ⇒ Integer (readonly)
The message ID
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def id @id end |
#inbox_id ⇒ Integer (readonly)
The inbox ID
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def inbox_id @inbox_id end |
#is_read ⇒ Boolean (readonly)
Whether the message has been read
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def is_read @is_read end |
#raw_path ⇒ String (readonly)
The path to the raw version of the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def raw_path @raw_path end |
#sent_at ⇒ String (readonly)
The timestamp when the message was sent
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def sent_at @sent_at end |
#smtp_information ⇒ Hash (readonly)
Information about SMTP
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def smtp_information @smtp_information end |
#subject ⇒ String (readonly)
The message subject
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def subject @subject end |
#text_body_size ⇒ Integer (readonly)
The size of the text body in bytes
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def text_body_size @text_body_size end |
#to_email ⇒ String (readonly)
The recipient’s email address
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def to_email @to_email end |
#to_name ⇒ String (readonly)
The recipient’s name
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def to_name @to_name end |
#txt_path ⇒ String (readonly)
The path to the text version of the email
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def txt_path @txt_path end |
#updated_at ⇒ String (readonly)
The timestamp when the message was last updated
29 30 31 |
# File 'lib/mailtrap/sandbox_message.rb', line 29 def updated_at @updated_at end |
Instance Method Details
#read? ⇒ Boolean
Returns Whether the message has been read.
55 56 57 |
# File 'lib/mailtrap/sandbox_message.rb', line 55 def read? is_read end |