Class: Mailtrap::TrackingOptOutsListResponse
- Inherits:
-
Struct
- Object
- Struct
- Mailtrap::TrackingOptOutsListResponse
- Defined in:
- lib/mailtrap/tracking_opt_outs_list_response.rb
Overview
Data Transfer Object for a paginated list of tracking opt-outs
Instance Attribute Summary collapse
-
#data ⇒ Array<TrackingOptOut>
readonly
The tracking opt-outs on this page.
-
#last_id ⇒ String?
readonly
Cursor for the next page, or nil if this is the last page.
Instance Attribute Details
#data ⇒ Array<TrackingOptOut> (readonly)
The tracking opt-outs on this page
8 9 10 |
# File 'lib/mailtrap/tracking_opt_outs_list_response.rb', line 8 def data @data end |
#last_id ⇒ String? (readonly)
Cursor for the next page, or nil if this is the last page
8 9 10 |
# File 'lib/mailtrap/tracking_opt_outs_list_response.rb', line 8 def last_id @last_id end |